@@ -1,12 +1,6 @@
 ## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ## DEPRECATED & DEFUNCT
 ## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-#' @export
-values <- function(...) {
-  .Defunct(msg = "values() is defunct in future (>= 1.20.0). Use value() instead.", package = .packageName)
-}
-
-
 #' @rdname sequential
 #' @export
 transparent <- function(...) {
